<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
</div>

<div align="center">

# nonebot-plugin-zsmeme

_✨发送寰宇重工中的表情 ✨_



<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>




## 📖 介绍

输入指令发送一张战双表情

## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-zsmeme

</details>

<details open>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<summary>pip</summary>

    pip install nonebot-plugin-zsmeme
</details>


## ⚙️ 配置

在 nonebot2 项目的`.env`文件中添加下表中的必填配置

| 配置项 | 必填 | 默认值 | 说明 |
|:-----:|:----:|:----:|:----:|
| 配置项 | 否 | 无 | 无 |

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 范围 | 说明 |
|:-----:|:----:|:----:|:----:|:----:|
| 战双表情 | 群员/主人 | 是否| 群聊 | 发送一张表情 |
### 效果图

![QQ图片20240420133703](https://github.com/shi-yingyingjiang/nonebot-plugin-zsmeme/assets/136897416/feb50e5e-fe0c-481a-a94f-c83c062129de)
